Index: /trunk/MagicSoft/Mars/Changelog
===================================================================
--- /trunk/MagicSoft/Mars/Changelog	(revision 2273)
+++ /trunk/MagicSoft/Mars/Changelog	(revision 2274)
@@ -15,4 +15,26 @@
    * mraw/MRawRunHeader.cc:
      - added an 'inf' to the log-stream
+  
+   * macros/status.C:
+     - added some more plots
+     - added some sanity chacks
+
+   * macros/sumevents.C, macros/sumeventserr.C, macros/sumeventsrms.C
+     macros/sumpedestalrms.C, macros/sumpedestals.C:
+     - fixed SetOptStat
+     
+   * manalysis/MBlindPixelCalc.[h,cc]:
+     - removed dangerous SetPixels(int, short*)
+     - changed Id to Idx
+     - fixed a bug in SetPixels which caused crashes
+     - renamed SetPixels to SetPixelIndices
+
+   * mhist/MHCamera.[h,cc]:
+     - removed SetOptStat and fOptStat - found a better solution
+     - fixed DistancetoPrimitive to show TPaveStat correctly
+     - Use GetPainter() instead of an own THistPainter
+
+   * mmain/MStatusDisplay.cc:
+     - some small changes to the layout
 
 
Index: /trunk/MagicSoft/Mars/macros/status.C
===================================================================
--- /trunk/MagicSoft/Mars/macros/status.C	(revision 2273)
+++ /trunk/MagicSoft/Mars/macros/status.C	(revision 2274)
@@ -31,5 +31,5 @@
 /////////////////////////////////////////////////////////////////////////////
 
-void status(const char *fname="cosmics.root")
+void status(const char *fname="*1947*cosmic*.root")
 {
     //
@@ -64,4 +64,10 @@
     plist.AddToList(&geomcam);
 
+    /*
+     MSrcPosCam src;
+     src.SetXY(1./geomcam.GetConvMm2Deg(), 0);
+     plist.AddToList(&src);
+     */
+
     //
     // Now setup the tasks and tasklist:
@@ -78,5 +84,10 @@
     MCerPhotCalc      ncalc;
 
-    MBlindPixelCalc   blind;
+    TArrayS blinds(2);
+    blinds[0] = 271;
+    blinds[1] = 291;
+
+    MBlindPixelCalc blind;
+    //blind.SetPixelIndices(blinds);
     blind.SetUseInterpolation();
 
@@ -87,15 +98,21 @@
     MCT1SupercutsCalc calc1;
 
+    MHCamEvent hist("PedestalRms");
+    hist.SetType(1);
+    plist.AddToList(&hist);
+
     // -------------------------------------------
     MFillH hfill0("Uncleaned [MHCamEvent]", "MCerPhotEvt");
-    MFillH hfill1("MHHillas", "MHillas");
-    MFillH hfill2("MHHillasExt");
-    MFillH hfill3("MHHillasExtSrc [MHHillasExt]", "MHillasSrc");
-    MFillH hfill4("MHHillasSrc","MHillasSrc");
-    MFillH hfill5("MHNewImagePar","MNewImagePar");
-    MFillH hfill6("MHStarMap", "MHillas");
-    MFillH hfill7("Cleaned [MHCamEvent]", "MCerPhotEvt");
-    MFillH hfill8("MHHadronness", "MHadronness");
-    MFillH hfill9("MHSigmaTheta");
+    MFillH hfill1("Pedestals [MHCamEvent]", "MPedestalCam");
+    MFillH hfill2("PedestalRms", "MPedestalCam");
+    MFillH hfill3("MHHillas", "MHillas");
+    MFillH hfill4("MHHillasExt");
+    MFillH hfill5("MHHillasExtSrc [MHHillasExt]", "MHillasSrc");
+    MFillH hfill6("MHHillasSrc","MHillasSrc");
+    MFillH hfill7("MHNewImagePar","MNewImagePar");
+    MFillH hfill8("MHStarMap", "MHillas");
+    MFillH hfill9("Cleaned [MHCamEvent]", "MCerPhotEvt");
+    MFillH hfill10("MHHadronness", "MHadronness");
+    MFillH hfill11("MHSigmaTheta");
 
     tlist.AddToList(&read);
@@ -103,6 +120,6 @@
     tlist.AddToList(&pnsb);
     tlist.AddToList(&ncalc);
+    tlist.AddToList(&blind);
     tlist.AddToList(&hfill0);
-    tlist.AddToList(&blind);
     //tlist.AddToList(&sgcal);
     tlist.AddToList(&clean);
@@ -117,5 +134,7 @@
     tlist.AddToList(&hfill6);
     tlist.AddToList(&hfill7);
-    //tlist.AddToList(&hfill8);
+    tlist.AddToList(&hfill8);
+    tlist.AddToList(&hfill9);
+    //tlist.AddToList(&hfill10);
 
     MEvtLoop evtloop;
@@ -131,4 +150,39 @@
     tlist.PrintStatistics();
 
+    MHCamera &uncl = *((MHCamEvent*)plist.FindObject("Uncleaned"))->GetHistByName();
+    MHCamera &hped = *((MHCamEvent*)plist.FindObject("Pedestals"))->GetHistByName();
+    MHCamera &hrms = *((MHCamEvent*)plist.FindObject("PedestalRms"))->GetHistByName();
+
+    for (int i=0; i<577; i++)
+    {
+        if (uncl.IsUsed(i))
+        {
+            if (uncl[i+1]>uncl.GetMean()+3*uncl.GetRMS())
+                cout << "Mean Charge of Pixel-Index #" << i << ": " << uncl[i+1] << " > 3*rms" << endl;
+            if (uncl[i+1]==0)
+                cout << "Mean Charge of Pixel-Index #" << i << ": " << uncl[i+1] << " <= 0" << endl;
+            if (uncl[i+1]<uncl.GetMean()-3*uncl.GetRMS())
+                cout << "Mean Charge of Pixel-Index #" << i << ": " << uncl[i+1] << " < 3*rms" << endl;
+        }
+        if (hped.IsUsed(i))
+        {
+            if (hped[i+1]>hped.GetMean()+1.5*hped.GetRMS())
+                cout << "Mean Pedestal of Pixel-Index #" << i << ": " << hped[i+1] << " > 1.5*rms" << endl;
+            if (hped[i+1]==0)
+                cout << "Mean Pedestal of Pixel-Index #" << i << ": " << hped[i+1] << " <= 0" << endl;
+            if (hped[i+1]<hped.GetMean()-1.5*hped.GetRMS())
+                cout << "Mean Pedestal of Pixel-Index #" << i << ": " << hped[i+1] << " < 1.5*rms" << endl;
+        }
+        if (hrms.IsUsed(i))
+        {
+            if (hrms[i+1]>hrms.GetMean()+4*hrms.GetRMS())
+                cout << "Mean PedestalRMS of Pixel-Index #" << i << ": " << hrms[i+1] << " > 4*rms" << endl;
+            if (hrms[i+1]==0)
+                cout << "Mean PedestalRMS of Pixel-Index #" << i << ": " << hrms[i+1] << " <= 0" << endl;
+            if (hrms[i+1]<hrms.GetMean()-4*hrms.GetRMS())
+                cout << "Mean PedestalRMS of Pixel-Index #" << i << ": " << hrms[i+1] << " < 4*rms" << endl;
+        }
+    }
+
     //
     // Make sure the display hasn't been deleted by the user while the
@@ -138,5 +192,5 @@
     {
         // Save data in a postscriptfile (status.ps)
-        d->SaveAsPS();
+        //d->SaveAsPS();
         /*
          * ----------- Write status to a root file ------------
Index: /trunk/MagicSoft/Mars/macros/sumevents.C
===================================================================
--- /trunk/MagicSoft/Mars/macros/sumevents.C	(revision 2273)
+++ /trunk/MagicSoft/Mars/macros/sumevents.C	(revision 2274)
@@ -90,24 +90,27 @@
     disp3->SetYTitle("\\sigma_{S} [%]");
 
-    disp1->SetOptStat(1111);
-    disp2->SetOptStat(1101);
-    disp3->SetOptStat(1101);
+    TText text(0.1, 0.5, &fname[fname.Last('/')+1]);
+    text.SetTextSize(0.015);
+    text.DrawClone();
 
     c->cd(1);
+    gStyle->SetOptStat(1111);
     disp1->Draw("hist");
+    gPad->Update();
 
     c->cd(2);
     gPad->SetLogy();
+    gStyle->SetOptStat(1101);
     disp2->Draw("hist");
+    gPad->Update();
 
     c->cd(3);
     gPad->SetLogy();
+    gStyle->SetOptStat(1101);
     disp3->Draw("hist");
+    gPad->Update();
 
     c->cd(4);
     gPad->SetBorderMode(0);
-    TText text(0.1, 0.95, &fname[fname.Last('/')+1]);
-    text.SetTextSize(0.03);
-    text.DrawClone();
     gPad->Divide(1,1);
     gPad->cd(1);
Index: /trunk/MagicSoft/Mars/macros/sumeventserr.C
===================================================================
--- /trunk/MagicSoft/Mars/macros/sumeventserr.C	(revision 2273)
+++ /trunk/MagicSoft/Mars/macros/sumeventserr.C	(revision 2274)
@@ -93,13 +93,27 @@
     disp3->SetYTitle("\\sigma_{S_{err}} [%]");
 
-    disp1->SetOptStat(1111);
-    disp2->SetOptStat(1101);
-    disp3->SetOptStat(1101);
+    TText text(0.1, 0.5, &fname[fname.Last('/')+1]);
+    text.SetTextSize(0.015);
+    text.DrawClone();
+
+    c->cd(1);
+    gStyle->SetOptStat(1111);
+    disp1->Draw("hist");
+    gPad->Update();
+
+    c->cd(2);
+    gPad->SetLogy();
+    gStyle->SetOptStat(1101);
+    disp2->Draw("hist");
+    gPad->Update();
+
+    c->cd(3);
+    gPad->SetLogy();
+    gStyle->SetOptStat(1101);
+    disp3->Draw("hist");
+    gPad->Update();
 
     c->cd(4);
     gPad->SetBorderMode(0);
-    TText text(0.1, 0.95, &fname[fname.Last('/')+1]);
-    text.SetTextSize(0.03);
-    text.DrawClone();
     gPad->Divide(1,1);
     gPad->cd(1);
@@ -117,15 +131,4 @@
     gPad->cd(1);
     disp3->Draw();
-
-    c->cd(1);
-    disp1->Draw("hist");
-
-    c->cd(2);
-    gPad->SetLogy();
-    disp2->Draw("hist");
-
-    c->cd(3);
-    gPad->SetLogy();
-    disp3->Draw("hist");
 
     c->SaveAs(fname(0, fname.Last('.')+1) + "ps");
Index: /trunk/MagicSoft/Mars/macros/sumeventsrms.C
===================================================================
--- /trunk/MagicSoft/Mars/macros/sumeventsrms.C	(revision 2273)
+++ /trunk/MagicSoft/Mars/macros/sumeventsrms.C	(revision 2274)
@@ -100,9 +100,21 @@
     disp3->SetYTitle("rel.err [%]");
 
+    TText text(0.1, 0.5, &fname[fname.Last('/')+1]);
+    text.SetTextSize(0.015);
+    text.DrawClone();
+
+    c->cd(1);
+    disp1->Draw("hist");
+
+    c->cd(2);
+    gPad->SetLogy();
+    disp2->Draw("hist");
+
+    c->cd(3);
+    gPad->SetLogy();
+    disp3->Draw("hist");
+
     c->cd(4);
     gPad->SetBorderMode(0);
-    TText text(0.1, 0.95, &fname[fname.Last('/')+1]);
-    text.SetTextSize(0.03);
-    text.DrawClone();
     gPad->Divide(1,1);
     gPad->cd(1);
@@ -120,15 +132,4 @@
     gPad->cd(1);
     disp3->Draw();
-
-    c->cd(1);
-    disp1->Draw("hist");
-
-    c->cd(2);
-    gPad->SetLogy();
-    disp2->Draw("hist");
-
-    c->cd(3);
-    gPad->SetLogy();
-    disp3->Draw("hist");
 
     c->SaveAs(fname(0, fname.Last('.')+1) + "ps");
Index: /trunk/MagicSoft/Mars/macros/sumpedestalrms.C
===================================================================
--- /trunk/MagicSoft/Mars/macros/sumpedestalrms.C	(revision 2273)
+++ /trunk/MagicSoft/Mars/macros/sumpedestalrms.C	(revision 2274)
@@ -94,22 +94,25 @@
     disp3->SetYTitle("\\sigma_{P_{rms}} [%]");
 
-    disp1->SetOptStat(1111);
-    disp2->SetOptStat(1101);
-    disp3->SetOptStat(1101);
+    TText text(0.1, 0.5, &fname[fname.Last('/')+1]);
+    text.SetTextSize(0.015);
+    text.DrawClone();
 
     c->cd(1);
+    gStyle->SetOptStat(1111);
     disp1->Draw("hist");
+    gPad->Update();
 
     c->cd(2);
+    gStyle->SetOptStat(1101);
     disp2->Draw("hist");
+    gPad->Update();
 
     c->cd(3);
+    gStyle->SetOptStat(1101);
     disp3->Draw("hist");
+    gPad->Update();
  
     c->cd(4);
     gPad->SetBorderMode(0);
-    TText text(0.1, 0.95, &fname[fname.Last('/')+1]);
-    text.SetTextSize(0.03);
-    text.DrawClone();
     gPad->Divide(1,1);
     gPad->cd(1);
Index: /trunk/MagicSoft/Mars/macros/sumpedestals.C
===================================================================
--- /trunk/MagicSoft/Mars/macros/sumpedestals.C	(revision 2273)
+++ /trunk/MagicSoft/Mars/macros/sumpedestals.C	(revision 2274)
@@ -90,22 +90,25 @@
     disp3->SetYTitle("\\sigma_{P} [%]");
 
-    disp1->SetOptStat(1111);
-    disp2->SetOptStat(1101);
-    disp3->SetOptStat(1101);
+    TText text(0.1, 0.5, &fname[fname.Last('/')+1]);
+    text.SetTextSize(0.015);
+    text.DrawClone();
 
     c->cd(1);
+    gStyle->SetOptStat(1111);
     disp1->Draw("hist");
+    gPad->Update();
 
     c->cd(2);
+    gStyle->SetOptStat(1101);
     disp2->Draw("hist");
+    gPad->Update();
 
     c->cd(3);
+    gStyle->SetOptStat(1101);
     disp3->Draw("hist");
+    gPad->Update();
 
     c->cd(4);
     gPad->SetBorderMode(0);
-    TText text(0.1, 0.95, &fname[fname.Last('/')+1]);
-    text.SetTextSize(0.03);
-    text.DrawClone();
     gPad->Divide(1,1);
     gPad->cd(1);
Index: /trunk/MagicSoft/Mars/mhist/MHCamera.cc
===================================================================
--- /trunk/MagicSoft/Mars/mhist/MHCamera.cc	(revision 2273)
+++ /trunk/MagicSoft/Mars/mhist/MHCamera.cc	(revision 2274)
@@ -81,5 +81,5 @@
 //  Default Constructor. To be used by the root system ONLY.
 //
-MHCamera::MHCamera() : TH1D(), fGeomCam(NULL), fColors(kItemsLegend), fOptStat(-1)
+MHCamera::MHCamera() : TH1D(), fGeomCam(NULL), fColors(kItemsLegend)
 {
     SetDirectory(NULL);
@@ -478,13 +478,5 @@
     {
         opt.ReplaceAll("hist", "");
-        Int_t mode = gStyle->GetOptStat();
-        TVirtualPad *save = gPad;
-        gPad=NULL;
-        gStyle->SetOptStat(fOptStat<0 ? mode : fOptStat);
-        gPad=save;
-        TH1D::Paint(o);
-        gPad=NULL;
-        gStyle->SetOptStat(mode);
-        gPad=save;
+        TH1D::Paint(opt);
         return;
     }
@@ -496,16 +488,20 @@
     Bool_t iscol = isbox ? !opt.Contains("nocol") : 1;
 
-    THistPainter paint;
-    if (!TestBit(TH1::kNoStats))
-    {
-        paint.SetHistogram(this);
-        paint.PaintStat(fOptStat<0?gStyle->GetOptStat():fOptStat, NULL);
+    GetPainter();
+    if (fPainter)
+    {
+        if (!TestBit(TH1::kNoStats))
+        {
+            fPainter->SetHistogram(this);
+            fPainter->PaintStat(gStyle->GetOptStat(), NULL);
+        }
+
+        // Paint primitives (pixels, color legend, photons, ...)
+        if (fPainter->InheritsFrom(THistPainter::Class()))
+            ((THistPainter*)fPainter)->PaintTitle();
     }
 
     // Update Contents of the pixels and paint legend
     Update(gPad->GetLogy(), isbox, iscol);
-
-    // Paint primitives (pixels, color legend, photons, ...)
-    paint.PaintTitle();
     PaintAxisTitle();
 }
@@ -950,4 +946,16 @@
 Int_t MHCamera::DistancetoPrimitive(Int_t px, Int_t py)
 {
+    const Int_t kMaxDiff = 7;
+
+    TPaveStats *box = (TPaveStats*)gPad->GetPrimitive("stats");
+    if (box)
+    {
+        const Double_t w = box->GetY2NDC()-box->GetY1NDC();
+        box->SetX1NDC(gStyle->GetStatX()-gStyle->GetStatW());
+        box->SetY1NDC(gStyle->GetStatY()-w);
+        box->SetX2NDC(gStyle->GetStatX());
+        box->SetY2NDC(gStyle->GetStatY());
+    }
+
     if (TString(GetDrawOption()).Contains("hist", TString::kIgnoreCase))
         return TH1D::DistancetoPrimitive(px, py);
@@ -959,5 +967,14 @@
             return 0;
     }
-    return 999999;
+
+    if (!box)
+        return 999999;
+
+    const Int_t dist = box->DistancetoPrimitive(px, py);
+    if (dist > kMaxDiff)
+        return 999999;
+
+    gPad->SetSelected(box);
+    return dist;
 }
 
Index: /trunk/MagicSoft/Mars/mhist/MHCamera.h
===================================================================
--- /trunk/MagicSoft/Mars/mhist/MHCamera.h	(revision 2273)
+++ /trunk/MagicSoft/Mars/mhist/MHCamera.h	(revision 2274)
@@ -35,5 +35,5 @@
     TList         *fNotify;      //!
 
-    Int_t          fOptStat;
+    //Int_t          fOptStat;
 
     //TGStatusBar   *fStatusBar;
@@ -55,5 +55,4 @@
     };
 
-    Bool_t IsUsed(Int_t idx) const { return TESTBIT(const_cast<TArrayC&>(fUsed)[idx], kIsUsed); }
     void   SetUsed(Int_t idx)      { SETBIT(fUsed[idx], kIsUsed); }
     void   ResetUsed(Int_t idx)    { CLRBIT(fUsed[idx], kIsUsed); }
@@ -73,4 +72,6 @@
     MHCamera(const MGeomCam &geom, const char *name="", const char *title="");
     ~MHCamera();
+
+    Bool_t IsUsed(Int_t idx) const { return TESTBIT(const_cast<TArrayC&>(fUsed)[idx], kIsUsed); }
 
     //void     AddPixContent(Int_t idx) const { AddBinContent(idx+1); }
@@ -135,5 +136,5 @@
 
     void  SetAutoScale(); // *MENU*
-    void  SetOptStat(Int_t os=-1); // *MENU*
+    //void  SetOptStat(Int_t os=-1); // *MENU*
 
     void  SetPix(const Int_t pixnum, const Int_t color, Float_t min, Float_t max);      // New function added by M.Lopez in 31-01-03
@@ -150,5 +151,5 @@
 
 inline void MHCamera::SetAutoScale() { fMinimum = fMaximum = -1111; }
-inline void MHCamera::SetOptStat(Int_t os) { fOptStat = os; }
+//inline void MHCamera::SetOptStat(Int_t os) { fOptStat = os; }
 
 #endif
Index: /trunk/MagicSoft/Mars/mmain/MStatusDisplay.cc
===================================================================
--- /trunk/MagicSoft/Mars/mmain/MStatusDisplay.cc	(revision 2273)
+++ /trunk/MagicSoft/Mars/mmain/MStatusDisplay.cc	(revision 2274)
@@ -289,5 +289,5 @@
     fList->Add(l);
 
-    TGLayoutHints *layb = new TGLayoutHints(kLHintsCenterX|kLHintsTop, 10, 10, 10, 10);
+    TGLayoutHints *layb = new TGLayoutHints(kLHintsCenterX|kLHintsTop, 10, 10, 5, 5);
     fList->Add(layb);
     f->AddFrame(l, layb);
@@ -309,5 +309,5 @@
         mars->Associate(this);
 
-        TGLayoutHints *lay2 = new TGLayoutHints(kLHintsCenterX|kLHintsCenterY, 10, 10, 10, 10);
+        TGLayoutHints *lay2 = new TGLayoutHints(kLHintsCenterX|kLHintsCenterY, 10, 10, 5, 5);
         fList->Add(lay2);
         f->AddFrame(mars, lay2);
@@ -324,4 +324,11 @@
     fList->Add(l);
     f->AddFrame(l, layb);
+
+    TGLayoutHints *layc = new TGLayoutHints(kLHintsCenterX|kLHintsTop, 10, 10, 0, 5);
+    fList->Add(layc);
+
+    l = new TGLabel(f, "<< Thomas Bretz >>");
+    fList->Add(l);
+    f->AddFrame(l, layc);
 }
 

Index: /trunk/MagicSoft/Mars/manalysis/MBlindPixelCalc.cc
===================================================================
--- /trunk/MagicSoft/Mars/manalysis/MBlindPixelCalc.cc	(revision 2273)
+++ /trunk/MagicSoft/Mars/manalysis/MBlindPixelCalc.cc	(revision 2274)
@@ -29,5 +29,5 @@
 //
 //  This is the specific image cleaning for a list of pixels. This task
 //  sets the pixels listed in fPixelsID to unused so they should not be
 //  used for analysis (eg calculation of hillas parameters).
 //
@@ -130,5 +130,5 @@
         return kTRUE;
 
-    const UShort_t size = fPixelsID.GetSize();
+    const UShort_t size = fPixelsIdx.GetSize();
 
     if (size == 0)
@@ -145,8 +145,8 @@
     // through the macros
 
-    UShort_t numids = fPixelsID.GetSize();
+    UShort_t numids = fPixelsIdx.GetSize();
 
     for(Int_t i = 0; i<numids; i++)
-	fPixels->SetPixelBlind(fPixelsID[i]);
+	fPixels->SetPixelBlind(fPixelsIdx[i]);
 
     return kTRUE;
@@ -167,5 +167,5 @@
 
     //
     // remove the pixels in fPixelsID if they are set to be used,
     // (set them to 'unused' state)
     //
@@ -174,12 +174,10 @@
         MCerPhotPix &pix = (*fEvt)[i];
 
-        const Int_t id = pix.GetPixId();
-
-        if (!fPixels->IsBlind(id))
+        const Int_t idx = pix.GetPixId();
+
+        if (!fPixels->IsBlind(idx))
             continue;
 
-        const MGeomPix &gpix = (*fGeomCam)[id];
-
-        const Int_t n = gpix.GetNumNeighbors();
+        const MGeomPix &gpix = (*fGeomCam)[idx];
 
         Int_t num = TESTBIT(fFlags, kUseCentralPixel) ? 1 : 0;
@@ -188,18 +186,19 @@
         perr[i]  = TESTBIT(fFlags, kUseCentralPixel) ? pix.GetErrorPhot()  : 0;
 
-        nphot[i] *= fGeomCam->GetPixRatio(id);
+        nphot[i] *= fGeomCam->GetPixRatio(idx);
         // FIXME: perr[i] ???
 
+        const Int_t n = gpix.GetNumNeighbors();
         for (int j=0; j<n; j++)
         {
-            const UShort_t nid = gpix.GetNeighbor(j);
-
-            if (fPixels->IsBlind(nid))
+            const UShort_t nidx = gpix.GetNeighbor(j);
+
+            if (fPixels->IsBlind(nidx))
                 continue;
 
-            const MCerPhotPix *evtpix = fEvt->GetPixById(nid);
+            const MCerPhotPix *evtpix = fEvt->GetPixById(nidx);
             if (evtpix)
             {
-                nphot[i] += evtpix->GetNumPhotons()*fGeomCam->GetPixRatio(nid);
+                nphot[i] += evtpix->GetNumPhotons()*fGeomCam->GetPixRatio(nidx);
                 perr[i]  += evtpix->GetErrorPhot();
                 // FIXME: perr[i] ???
@@ -208,5 +207,5 @@
         }
 
-        nphot[i] /= num*fGeomCam->GetPixRatio(id);
+        nphot[i] /= num*fGeomCam->GetPixRatio(idx);
         perr[i]  /= num/*FIXME:???*/;
     }
@@ -235,5 +234,5 @@
 
     //
     // remove the pixels in fPixelsID if they are set to be used,
     // (set them to 'unused' state)
     //
@@ -244,5 +243,4 @@
         if (fPixels->IsBlind(pix.GetPixId()))
             pix.SetPixelUnused();
-
     }
 }
@@ -264,17 +262,4 @@
 // --------------------------------------------------------------------------
 //
-//  Set pixels to no be used. 
-//  This member function (public) should be called from the macro (or
-//  analysis program) setting the desired blind pixels.
-//  In the future, the blind pixels may be extracted from information which
-//  is already in the root file.  
-//
-void MBlindPixelCalc::SetPixels(Int_t num, Short_t *ids)
-{
-    fPixelsID.Adopt(num, ids);
-}
-
-// --------------------------------------------------------------------------
-//
 //  - Check whether pixels to disable are available. If pixels are
 //    given by the user nothing more is done.
@@ -290,5 +275,5 @@
     // If pixels are given by the user, we are already done
     //
-    if (fPixelsID.GetSize() > 0)
+    if (fPixelsIdx.GetSize() > 0)
         return kTRUE;
 
@@ -355,11 +340,11 @@
         out << "   " << GetUniqueName() << ".SetUseCentralPixel();" << endl;
 
-    if (fPixelsID.GetSize()==0)
+    if (fPixelsIdx.GetSize()==0)
         return;
 
     out << "   {" << endl;
     out << "      TArrayS dummy;" << endl;
-    for (int i=0; i<fPixelsID.GetSize(); i++)
-        out << "      dummy[" << i << "]=" << ((TArrayS)fPixelsID)[i] << ";" << endl;
+    for (int i=0; i<fPixelsIdx.GetSize(); i++)
+        out << "      dummy[" << i << "]=" << ((TArrayS)fPixelsIdx)[i] << ";" << endl;
     out << "      " << GetUniqueName() << ".SetPixels(dummy);" << endl;
     out << "   }" << endl;
@@ -29,5 +29,5 @@
 //
 //  This is the specific image cleaning for a list of pixels. This task
-//  sets the pixels listed in fPixelsID to unused so they should not be
+//  sets the pixels listed in fPixelsIdx to unused so they should not be
 //  used for analysis (eg calculation of hillas parameters).
 //
@@ -167,5 +167,5 @@
 
     //
-    // remove the pixels in fPixelsID if they are set to be used,
+    // remove the pixels in fPixelsIdx if they are set to be used,
     // (set them to 'unused' state)
     //
@@ -235,5 +234,5 @@
 
     //
-    // remove the pixels in fPixelsID if they are set to be used,
+    // remove the pixels in fPixelsIdx if they are set to be used,
     // (set them to 'unused' state)
     //
Index: /trunk/MagicSoft/Mars/manalysis/MBlindPixelCalc.h
===================================================================
--- /trunk/MagicSoft/Mars/manalysis/MBlindPixelCalc.h	(revision 2273)
+++ /trunk/MagicSoft/Mars/manalysis/MBlindPixelCalc.h	(revision 2274)
@@ -21,5 +21,5 @@
     MGeomCam     *fGeomCam; //!
 
-    TArrayS fPixelsID;  // Pixel IDs for blind pixels, which are entered by the user.
+    TArrayS fPixelsIdx;  // Pixel Indices for blind pixels, which are entered by the user.
 
     Byte_t fFlags;      // flag for the method which is used
@@ -55,6 +55,5 @@
     }
 
-    void SetPixels(Int_t num, Short_t *ids);
-    void SetPixels(const TArrayS pix) { SetPixels((Int_t)pix.GetSize(), (Short_t*)pix.GetArray()); }
+    void SetPixelIndices(const TArrayS &pix) { fPixelsIdx = pix; }
     virtual Bool_t ReInit(MParList *pList);
 